package sluzby;

import javax.swing.table.AbstractTableModel;
import model.Matice;

/**
 * Třída tableModel pro obsluhu uživatelského rozhraní
 *
 * @author Matěj Fries
 */
public class TableModelSemAnalyza extends AbstractTableModel
{

    /**
     * Pole hodnot ve formátu string
     */
    private String[][] pole;
    /**
     * Pole názů sloupců
     */
    private String[] sloupce;

    /**
     * Konstruktor bez parametrů
     */
    public TableModelSemAnalyza()
    {
        pole = new String[2][2];
        sloupce = new String[]
        {
            " ", " "
        };
    }

    /**
     * Konstruktor
     *
     * @param matice matice s hodnotami
     * @param sloupce pole s názvy sloupců
     */
    public TableModelSemAnalyza(Matice matice, String[] sloupce)
    {
        this.pole = MaticeNaStringPole(matice);
        this.sloupce = sloupce;
    }

    /**
     * Konstruktor
     *
     * @param pole pole s hodnotami
     * @param sloupce pole názvů sloupců
     */
    public TableModelSemAnalyza(String[][] pole, String[] sloupce)
    {
        this.pole = pole.clone();
        this.sloupce = sloupce;
    }

    /**
     * Metoda pro aktualizace hodnot v poli
     *
     * @param matice matice s hodnotami
     */
    public void updatePole(Matice matice)
    {
        this.pole = MaticeNaStringPole(matice);
    }

    /**
     * Metoda pro aktualizace hodnot v poli
     *
     * @param pole pole s hodnotami
     */
    public void updatePole(String[][] pole)
    {
        this.pole = pole.clone();
    }

    /**
     * Metoda pro nastavení názvu sloupců
     *
     * @param sloupce pole s názvy sloupců
     */
    public void setSloupce(String[] sloupce)
    {
        this.sloupce = sloupce;
    }

    /**
     * Mtoda pro získání počtu řádků
     *
     * @return počet řádků
     */
    @Override
    public int getRowCount()
    {
        return pole.length;
    }

    /**
     * Metoda pro získání počtu sloupců
     *
     * @return počet sloupců
     */
    @Override
    public int getColumnCount()
    {
        return pole[0].length;
    }

    /**
     * Vrací určenou hodnotu
     *
     * @param rowIndex číslo řádku
     * @param columnIndex číslo sloupce
     * @return hodnota
     */
    @Override
    public Object getValueAt(int rowIndex, int columnIndex)
    {
        return pole[rowIndex][columnIndex];
    }

    /**
     * Vrací název sloupce
     *
     * @param column číslo sloupce
     * @return název sloupce
     */
    @Override
    public String getColumnName(int column)
    {
        return sloupce[column];
    }

    /**
     * Privátní metoda pro převod matice na pole textových řetězců
     *
     * @param mat matice k převedení
     * @return dvojrozměrné poel stringů
     */
    private String[][] MaticeNaStringPole(Matice mat)
    {
        double[][] poleDouble = mat.getArrayCopy();
        String[][] poleString = new String[poleDouble.length][poleDouble[0].length];
        for (int x = 0; x < poleDouble.length; x++)
        {
            for (int y = 0; y < poleDouble[0].length; y++)
            {
                poleString[x][y] = Double.toString(poleDouble[x][y]);

            }
        }

        return poleString;
    }
}
